#!/bin/bash
#
# This module gathers diagnostic information about 
# a Kolibri installation and attempts a few known 
# light fixes issues. It is meant only to be 
# uploaded via the settings tab as a .zip
#--------------------------------------------------

DATE=$(date +'%m/%d/%Y')
DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )"
LOGFILE="${DIR}/diagnostic.log"
LOGGING=1

# Log message to console and file
# MSG is set for chk_f to log 
function log(){
  MSG=$1

  if [ $LOGGING = 1 ]; then
    echo -e "SETUP: $1" | tee -a $LOGFILE
    return
  fi
    
  echo -e "SETUP: $1"
}

# Check for error status in previous command 
function check(){
  if [ "${?}" -ne "0" ]; then
    echo "FAILED: '${MSG}'"
    exit 1
  fi
}

function diagnoseKolibri(){
  log "Starting Kolibri diagnostic"
  log "Checking mounted drives"
  lsblk 
  log "Getting Kolibri version"
  sudo kolibri --version
  
  log "Getting Kolibri status"
  sudo systemctl status kolibri
  
  log "Stopping Kolibri"
  sudo systemctl stop Kolibri 
  
  if [ -d /root/.kolibri/process_cache ]; then
    log "Deleting root Kolibri cache"
    sudo rm -rf /root/.kolibri/process_cache
  fi
  
  if [ -d /.data/RACHEL/.kolibri/process_cache ]; then 
    log "Removing process cache"
    sudo rm -rf /.data/RACHEL/.kolibri/process_cache
  fi

  log "Restarting Kolibri"
  sudo systemctl restart kolibri
  
  log "Checking Kolibri status"
  sudo systemctl status kolibri
  
  log "Finished Kolibri Diagnostic"
}


diagnoseKolibri

